- 2021-02-24, jgliss	Finalise complete set of tests for atmosphere module
- 2021-02-24, jgliss	Rename function density to air_density in atmosphere module
- 2021-02-24, jgliss	Pass ref_p to pressure function in density
- 2021-02-22, jgliss	Update handling and default locations of local topodata storage; add new tests
- 2021-02-22, jgliss	Remove __future__ import
- 2021-02-22, jgliss	Update README
- 2021-02-22, jgliss	Rename geonum_env_py3.yml to geonum_env.yml
- 2021-02-22, jgliss	Update and clarify dependencies; modify tests (cf https://github.com/tkrajina/srtm.py/issues/51)
- 2020-01-20, Jonas Gliss	Added option to check if all values are NaN in TopoDataAccess
- 2019-10-24, Jonas Gliss	Fixed bug in computation of atm. pressure related to input temperature T
- 2019-05-18, jgliss	Removed global matplotlib imports in all modules (due to import failure on circleci for registration in conda-forge) and updated version to 1.4.3
